@@ -30,15 +30,22 @@ class AttributeEnum(str, BaseEnum):
 
 
 class StatusTypes(AttributeEnum):
-    Ongoing = 'Ongoing'
-    Completed = 'Completed'
-    Haitus = 'Haitus'
-    Dropped = 'Dropped'
-    ComingSoon = 'Comic Soon'
+    Ongoing = 'ongoing'
+    Completed = 'completed'
+    Hiatus = 'hiatus'
+    Dropped = 'dropped'
+    ComingSoon = 'comic Soon'
 
 
 class ComicTypesLanguage(AttributeEnum):
     manga = 'ja'
     manhua = 'zh'
     manhwa = 'ko'
-    webtoon = 'en'
\ No newline at end of file
+    webtoon = 'en'
+
+class ContentRatingTypes(AttributeEnum):
+    """Lowest to Highest order Content Rating"""
+    Safe = 'safe'
+    Suggestive = 'suggestive'
+    Erotica = 'erotica'
+    Pornographic = 'pornographic'
\ No newline at end of file
